@@ -1,15 +1,22 @@
 // ライセンス: GPL2
 
+//#define _DEBUG
+#include "jddebug.h"
+
 #include "preference.h"
 
 #include "dbtree/interface.h"
 #include "dbtree/boardbase.h"
 
+#include "skeleton/msgdiag.h"
+
 #include "jdlib/miscutil.h"
+#include "jdlib/misctime.h"
 
 #include "cache.h"
 #include "command.h"
 #include "global.h"
+#include "viewfactory.h"
 
 using namespace BOARD;
 
@@ -23,10 +30,12 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
       m_frame_cookie( "クッキー＆Hana" ),
       m_button_cookie( "削除" ) ,
 
+      m_check_live( "実況する" ),
+
       m_proxy_frame( "読み込み用" ),
       m_proxy_frame_w( "書き込み用" ),
 
-      m_label_name( "板タイトル：" + DBTREE::board_name( get_url() ), Gtk::ALIGN_LEFT ),
+      m_label_name( false, "板タイトル：", DBTREE::board_name( get_url() ) ),
       m_label_url( false, "板のURL：", DBTREE::url_boardbase( get_url() ) ),
       m_label_cache( false, "ローカルキャッシュのルートパス", CACHE::path_board_root( DBTREE::url_boardbase( get_url() ) ) ),
 
@@ -34,8 +43,13 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
       m_label_noname( false, "デフォルト名無し：", DBTREE::default_noname( get_url() ) ),
       m_label_line( false, "1レスの最大改行数：" ),
       m_label_byte( false, "1レスの最大バイト数：" ),
+      m_entry_max_res( false, "最大レス数：" ),
+      m_label_last_access( false, "最終アクセス日時 ：" ),
+      m_label_modified( false, "最終更新日時 ：" ),
+      m_button_clearmodified( "日時クリア" ),
       m_label_samba( false, "書き込み規制秒数 (Samba24) ：" ),
-      m_button_clearsamba( "秒数クリア" )
+      m_button_clearsamba( "秒数クリア" ),
+      m_localrule( NULL )
 {
     m_edit_cookies.set_editable( false );
 
@@ -83,14 +97,52 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
 
     m_frame_cookie.add( m_hbox_cookie );
 
+    // 実況
+    const int live_sec = DBTREE::board_get_live_sec( get_url() );
+    m_label_live.set_text( "実況時の更新間隔(秒)：" );
+
+    m_spin_live.set_range( MIN_LIVE_RELOAD_SEC, 1200 );
+    m_spin_live.set_increments( 1, 1 );
+    m_spin_live.set_value( MAX( live_sec, MIN_LIVE_RELOAD_SEC ) );
+    if( live_sec ){
+        m_check_live.set_active( true );
+        m_spin_live.set_sensitive( true );
+    }
+    else{
+        m_check_live.set_active( false );
+        m_spin_live.set_sensitive( false );
+    }
+    m_check_live.signal_toggled().connect( sigc::mem_fun(*this, &Preferences::slot_check_live ) );
+
+    m_hbox_live.set_spacing( 4 );
+    m_hbox_live.pack_start( m_label_live, Gtk::PACK_SHRINK );
+    m_hbox_live.pack_start( m_spin_live, Gtk::PACK_SHRINK );
+    m_hbox_live.pack_start( m_check_live, Gtk::PACK_SHRINK );
 
     // 一般ページのパッキング
     m_label_line.set_text( MISC::itostr( DBTREE::line_number( get_url() ) * 2 ) );
     m_label_byte.set_text( MISC::itostr( DBTREE::message_count( get_url() ) ) );
-    m_label_samba.set_text( MISC::itostr( DBTREE::board_samba_sec( get_url() ) ) );
+
+    int max_res = DBTREE::board_get_number_max_res( get_url() );
+    if( ! max_res ) m_entry_max_res.set_text( "未設定 " );
+    else m_entry_max_res.set_text( MISC::itostr( max_res ) );
+
+    const time_t last_access = DBTREE::board_last_access_time( get_url() );
+    if( last_access ) m_label_last_access.set_text( MISC::timettostr( last_access ) );
+
+    if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
+    else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
+
+    m_button_clearmodified.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_modified ) );
+    m_hbox_modified.pack_start( m_label_modified );
+    m_hbox_modified.pack_start( m_button_clearmodified, Gtk::PACK_SHRINK );    
+
+    const int samba_sec = DBTREE::board_samba_sec( get_url() );
+    if( ! samba_sec ) m_label_samba.set_text( "未取得" );
+    else m_label_samba.set_text( MISC::itostr( samba_sec ) );
 
     m_button_clearsamba.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_samba ) );
-    m_hbox_samba.pack_start( m_label_samba, Gtk::PACK_SHRINK );
+    m_hbox_samba.pack_start( m_label_samba );
     m_hbox_samba.pack_start( m_button_clearsamba, Gtk::PACK_SHRINK );    
 
     m_vbox.set_border_width( 16 );
@@ -102,10 +154,17 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_vbox.pack_start( m_label_noname, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_label_line, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_label_byte, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_entry_max_res, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_label_last_access, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_hbox_modified, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_hbox_live, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_samba, Gtk::PACK_SHRINK );
     m_vbox.pack_end( m_frame_cookie, Gtk::PACK_SHRINK );
     m_vbox.pack_end( m_frame_write, Gtk::PACK_SHRINK );
 
+    // ローカルルール
+    m_localrule = CORE::ViewFactory( CORE::VIEW_ARTICLEINFO, get_url() );
+
     // プロキシ
     m_vbox_proxy.set_border_width( 16 );
     m_vbox_proxy.set_spacing( 8 );
@@ -157,7 +216,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     for( it = list_regex.begin(); it != list_regex.end(); ++it ) if( ! ( *it ).empty() ) str_regex += ( *it ) + "\n";
     m_edit_regex.set_text( str_regex );
 
-    m_label_warning.set_text( "ここでのあぼーん設定は「" +  DBTREE::board_name( get_url() ) + "」板の全スレに適用されます。\n\n設定のし過ぎは板内の全スレの表示速度を低下させます。\n\n指定のし過ぎに気を付けてください。\n\nなおNG IDはJDを再起動するとリセットされます。" );
+    m_label_warning.set_text( "ここでのあぼーん設定は「" +  DBTREE::board_name( get_url() ) + "」板の全スレに適用されます。\n\n設定のし過ぎは板内の全スレの表示速度を低下させます。\n\n設定のし過ぎに気を付けてください。\n\nなおNG IDはJDを再起動するとリセットされます。" );
 
     m_notebook_abone.append_page( m_label_warning, "注意" );
     m_notebook_abone.append_page( m_edit_id, "NG ID" );
@@ -167,6 +226,33 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
 
     // スレッドあぼーん
 
+    // スレ数、時間
+    m_label_abone_thread.set_text( "以下の数字が0の時は、設定メニューの全体あぼ〜ん設定で指定した数字が用いられます。\nまたキャッシュにログがあるスレはあぼ〜んされません。\n\n" );
+
+    m_label_number.set_text( "レス以上のスレをあぼ〜ん" );
+    m_spin_number.set_range( 0, 1001 );
+    m_spin_number.set_increments( 1, 1 );
+    m_spin_number.set_value( DBTREE::get_abone_number_thread( get_url() ) );
+            
+    m_hbox_number.set_spacing( 4 );
+    m_hbox_number.pack_start( m_spin_number, Gtk::PACK_SHRINK );
+    m_hbox_number.pack_start( m_label_number, Gtk::PACK_SHRINK );
+
+    m_label_hour.set_text( "時間以上スレ立てから経過したスレをあぼ〜ん" );
+    m_spin_hour.set_range( 0, 1000 );
+    m_spin_hour.set_increments( 1, 1 );
+    m_spin_hour.set_value( DBTREE::get_abone_hour_thread( get_url() ) );
+            
+    m_hbox_hour.set_spacing( 4 );
+    m_hbox_hour.pack_start( m_spin_hour, Gtk::PACK_SHRINK );
+    m_hbox_hour.pack_start( m_label_hour, Gtk::PACK_SHRINK );
+
+    m_vbox_abone_thread.set_border_width( 16 );
+    m_vbox_abone_thread.set_spacing( 8 );
+    m_vbox_abone_thread.pack_start( m_label_abone_thread, Gtk::PACK_SHRINK );
+    m_vbox_abone_thread.pack_start( m_hbox_number, Gtk::PACK_SHRINK );
+    m_vbox_abone_thread.pack_start( m_hbox_hour, Gtk::PACK_SHRINK );
+
     // スレあぼーん
     std::list< std::string > list_thread = DBTREE::get_abone_list_thread( get_url() );
     for( it = list_thread.begin(); it != list_thread.end(); ++it ) if( ! ( *it ).empty() ) str_thread += ( *it ) + "\n";
@@ -182,6 +268,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     for( it = list_regex_thread.begin(); it != list_regex_thread.end(); ++it ) if( ! ( *it ).empty() ) str_regex_thread += ( *it ) + "\n";
     m_edit_regex_thread.set_text( str_regex_thread );
 
+    m_notebook_abone_thread.append_page( m_vbox_abone_thread, "一般" );
     m_notebook_abone_thread.append_page( m_edit_thread, "NG スレタイトル" );
     m_notebook_abone_thread.append_page( m_edit_word_thread, "NG ワード" );
     m_notebook_abone_thread.append_page( m_edit_regex_thread, "NG 正規表現" );
@@ -191,10 +278,12 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_edit_settingtxt.set_text( DBTREE::settingtxt( get_url() ) );
 
     m_notebook.append_page( m_vbox, "一般" );
+    m_notebook.append_page( *m_localrule, "ローカルルール" );
     m_notebook.append_page( m_vbox_proxy, "プロキシ設定" );
     m_notebook.append_page( m_notebook_abone, "あぼーん設定(スレビュー)" );
     m_notebook.append_page( m_notebook_abone_thread, "あぼーん設定(スレ一覧)" );
     m_notebook.append_page( m_edit_settingtxt, "SETTING.TXT" );
+    m_notebook.signal_switch_page().connect( sigc::mem_fun( *this, &Preferences::slot_switch_page ) );
 
     get_vbox()->pack_start( m_notebook );
     set_title( "「" + DBTREE::board_name( get_url() ) + "」のプロパティ" );
@@ -203,10 +292,29 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
 }
 
 
+Preferences::~Preferences()
+{
+    if( m_localrule ) delete m_localrule;
+    m_localrule = NULL;
+}
+
+
+void Preferences::slot_clear_modified()
+{
+    DBTREE::board_set_date_modified( get_url(), "" );
+
+    if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
+    else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
+}
+
+
 void Preferences::slot_clear_samba()
 {
     DBTREE::board_set_samba_sec( get_url(), 0 );
-    m_label_samba.set_text( MISC::itostr( DBTREE::board_samba_sec( get_url() ) ) );
+
+    const int samba_sec = DBTREE::board_samba_sec( get_url() );
+    if( ! samba_sec ) m_label_samba.set_text( "未取得" );
+    else m_label_samba.set_text( MISC::itostr( samba_sec ) );
 }
 
 
@@ -219,6 +327,27 @@ void Preferences::slot_delete_cookie()
 }
 
 
+void Preferences::slot_check_live()
+{
+    if( m_check_live.get_active() ){
+        m_spin_live.set_sensitive( true );
+        SKELETON::MsgDiag mdiag( NULL, "実況を許された板以外では実況しないようにして下さい。\n\n実況状態のまま閉じたスレはJD終了時に削除されます。詳しくはマニュアルの実況の項目を参照して下さい。",
+                                 false, Gtk::MESSAGE_WARNING );
+        mdiag.run();
+    }
+    else m_spin_live.set_sensitive( false );
+}
+
+
+void Preferences::slot_switch_page( GtkNotebookPage*, guint page )
+{
+    if( m_notebook.get_nth_page( page ) == m_localrule ){
+        m_localrule->set_command( "clear_screen" );
+        m_localrule->set_command( "append_html", DBTREE::localrule( get_url() ) );
+    }
+}
+
+
 //
 // OK 押した
 //
@@ -251,7 +380,9 @@ void Preferences::slot_ok_clicked()
     std::list< std::string > list_thread = MISC::get_lines( m_edit_thread.get_text() );
     std::list< std::string > list_word_thread = MISC::get_lines( m_edit_word_thread.get_text() );
     std::list< std::string > list_regex_thread = MISC::get_lines( m_edit_regex_thread.get_text() );
-    DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread );  // 板の再描画も行われる
+    const int number = m_spin_number.get_value_as_int();
+    const int hour = m_spin_hour.get_value_as_int();
+    DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread, number, hour );  // 板の再描画も行われる
 
     // 書き込み設定
     DBTREE::board_set_check_noname( get_url(), m_check_noname.get_active() );
@@ -261,5 +392,18 @@ void Preferences::slot_ok_clicked()
     if( tmpmail.empty() ) tmpmail = JD_MAIL_BLANK; // 空白の場合 JD_MAIL_BLANK をセットする
     DBTREE::board_set_write_mail( get_url(), tmpmail );
 
+    // 実況間隔
+    int live_sec = 0;
+    if( m_check_live.get_active() ) live_sec = m_spin_live.get_value_as_int();
+    DBTREE::board_set_live_sec( get_url(), live_sec );
+    CORE::core_set_command( "redraw_article_toolbar" );
+
     DBTREE::board_save_info( get_url() );
 }
+
+
+bool Preferences::slot_timeout( int timer_number )
+{
+    if( m_localrule ) m_localrule->clock_in();    
+    return true;
+}
