@@ -55,9 +55,6 @@ namespace CORE
 {
     class MainToolBar;
     class DND_Manager;
-    class HistoryMenuThread;
-    class HistoryMenuBoard;
-    class HistoryMenuClose;
 
     class Core : public SKELETON::Dispatchable
     {
@@ -78,7 +75,7 @@ namespace CORE
         // 右ペーンで使用するwidget
         SKELETON::JDVBox m_vbox_article;
         SKELETON::JDVBox m_vbox_toolbar;
-        SKELETON::JDNotebook m_notebook;
+        SKELETON::JDNotebook m_notebook_right;
         bool m_imagetab_shown;
         SKELETON::JDVPaned m_vpaned_message; // 埋め込み書き込みビュー用
 
@@ -93,9 +90,6 @@ namespace CORE
 
         Glib::RefPtr< Gtk::ActionGroup > m_action_group;
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
-        HistoryMenuThread* m_histmenu_thread;
-        HistoryMenuBoard* m_histmenu_board;
-        HistoryMenuClose* m_histmenu_close;
         bool m_enable_menuslot;
 
         // 初期設定中
@@ -132,6 +126,9 @@ namespace CORE
 
         void set_maintitle();
 
+        void slot_realize();
+        void slot_style_changed( Glib::RefPtr< Gtk::Style > );
+
         void slot_activate_menubar();
 
         void slot_toggle_save_postlog();
@@ -170,14 +167,18 @@ namespace CORE
         void slot_board_pref();
         void slot_article_pref();
         void slot_image_pref();
+        void slot_usrcmd_pref();
+        void slot_filter_pref();
         void slot_setup_browser();
         void slot_setup_abone();
         void slot_setup_abone_thread();
         void slot_toggle_abone_transp_chain();
+        void slot_setup_live();
 
         void slot_show_bbs();
         void slot_show_old2ch();
         void slot_show_manual();
+        void slot_aboutconfig();
         void slot_show_about();
         void slot_quit();
         void slot_reload_list();
@@ -188,11 +189,16 @@ namespace CORE
         void slot_toggle_online();
         void slot_toggle_login2ch();
         void slot_toggle_loginbe();
+        void slot_toggle_loginp2();
         void toggle_menubar();
+        void toggle_flat_button();
+        void toggle_post_mark();
         void toggle_sidebar();
         void slot_search_cache_board();
         void slot_search_cache();
         void slot_search_title();
+        void slot_show_postlog();
+        void slot_live_start_stop();
         void slot_show_hide_leftpane( int mode );
         void slot_toggle_toolbarpos( int pos );
         void slot_toggle_toolbarbbslist();
@@ -239,6 +245,8 @@ namespace CORE
 
         bool slot_focus_out_event( GdkEventFocus* ev );
         bool slot_focus_in_event( GdkEventFocus* ev );
+
+        // URL entryでenterを押した
         void slot_active_url();
 
         // あるadminがemptyになったので他のadminにスイッチ
