@@ -123,6 +123,15 @@ namespace DBTREE
         // samba(秒)
         time_t m_samba_sec;
 
+        // 実況時の更新間隔(秒)
+        time_t m_live_sec;
+
+        // 最終アクセス時刻
+        time_t m_last_access_time;
+
+        // 最大レス数
+        int m_number_max_res;
+
         char* m_rawdata;
         int m_lng_rawdata;
 
@@ -204,8 +213,8 @@ namespace DBTREE
         // url がこの板のものかどうか
         virtual bool equal( const std::string& url );
 
-        // 移転などで板のルートを変更する
-        void update_root( const std::string& root );
+        // 移転などで板のルートやパスを変更する
+        void update_url( const std::string& root, const std::string& path_board );
 
         const std::string& get_root() const{ return m_root; }
         const std::string& get_path_board() const { return m_path_board; }
@@ -213,6 +222,7 @@ namespace DBTREE
         const std::string& get_id() const { return m_id; }
         const std::string& get_charset() const { return m_charset; }
         const std::string& get_name() const { return m_name; }
+        void update_name( const std::string& name );
         const std::string& get_subjecttxt() const { return m_subjecttxt; }
 
         // ダウンロード、書き込み時のエージェント名やプロキシ
@@ -254,15 +264,15 @@ namespace DBTREE
         // url がスレッドのURLで無い時はempty()が返る
         // もしurlが移転前の旧ホストのものだったら対応するarticlebaseクラスに旧ホスト名を知らせる
         // (例) url =  "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"のとき、
-        // "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15
-        const std::string url_dat( const std::string& url, int& num_from, int& num_to ); 
+        // "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15, num_str = 12-15
+        virtual const std::string url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str ); 
 
         // スレの url を read.cgi型のurlに変換
         // url がスレッドのURLで無い時はempty()が返る
         // num_from と num_to が 0 で無い時はスレ番号を付ける
         // (例) "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15 のとき
         // "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"
-        virtual const std::string url_readcgi( const std::string& url, int num_from, int num_to );
+        const std::string url_readcgi( const std::string& url, int num_from, int num_to );
 
         // subject.txt の URLを取得
         // (例) "http://www.hoge2ch.net/hogeboard/subject.txt"
@@ -290,7 +300,7 @@ namespace DBTREE
 
         // read.cgi のURLのパスを返す
         // (例) "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345" なら "/test/read.cgi/hogeboard/"
-        virtual const std::string url_readcgipath();
+        const std::string url_readcgipath();
 
         // bbscgi のURLのベースアドレス
         const std::string url_bbscgibase();
@@ -300,9 +310,9 @@ namespace DBTREE
 
         // article クラスのポインタ取得
         // それぞれの違いはソースのコメントを参照
-        ArticleBase* get_article( const std::string id );
-        ArticleBase* get_article_create( const std::string id );
-        ArticleBase* get_article_fromURL( const std::string url );
+        ArticleBase* get_article( const std::string& id );
+        ArticleBase* get_article_create( const std::string& id );
+        ArticleBase* get_article_fromURL( const std::string& url );
 
         void download_subject();
 
@@ -381,6 +391,17 @@ namespace DBTREE
         void set_samba_sec( time_t sec ){ m_samba_sec = sec; }
         time_t get_write_leftsec(); // 書き込み可能までの残り秒
 
+        // 実況の秒数
+        const time_t get_live_sec() const{ return m_live_sec; }
+        void set_live_sec( time_t sec ){ m_live_sec = sec; }
+
+        // 最終アクセス時刻
+        const time_t get_last_access_time() const{ return m_last_access_time; }
+
+        // 最大レス数
+        const int get_number_max_res() const{ return m_number_max_res; }
+        void set_number_max_res( const int number ){ m_number_max_res = number; }
+
         // 板情報の取得
         void read_info();
 
