@@ -24,7 +24,10 @@ void DBTREE::create_root()
 
 void DBTREE::delete_root()
 {
-    if( instance_dbtree_root ) delete instance_dbtree_root;
+    if( instance_dbtree_root ){
+        instance_dbtree_root->terminate_load();
+        delete instance_dbtree_root;
+    }
 }
 
 
@@ -82,9 +85,9 @@ const std::string DBTREE::url_datbase( const std::string& url )
 
 
 // urlをdat型のurlに変換
-const std::string DBTREE::url_dat( const std::string& url, int& num_from, int& num_to )
+const std::string DBTREE::url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str )
 {
-    return DBTREE::get_board( url )->url_dat( url, num_from, num_to );
+    return DBTREE::get_board( url )->url_dat( url, num_from, num_to, num_str );
 }
 
 
@@ -92,7 +95,8 @@ const std::string DBTREE::url_dat( const std::string& url, int& num_from, int& n
 const std::string DBTREE::url_dat( const std::string& url )
 {
     int num_from, num_to;
-    return url_dat( url, num_from, num_to );
+    std::string num_str;
+    return url_dat( url, num_from, num_to, num_str );
 }
 
 
@@ -135,15 +139,26 @@ const std::string DBTREE::url_subbbscgi_new( const std::string& url )
 }
 
 
+// 簡易版
 const std::string  DBTREE::is_board_moved( const std::string& url )
 {
     return get_root()->is_board_moved( url );
 }
 
-
-void DBTREE::update_board( const std::string& url, const std::string& name, const std::string& basicauth, bool etc )
+const std::string  DBTREE::is_board_moved( const std::string& url,
+                                        std::string& old_root,
+                                        std::string& old_path_board,
+                                        std::string& new_root,
+                                        std::string& new_path_board
+    )
 {
-    get_root()->update_board( url, name, basicauth, etc );
+    return get_root()->is_board_moved( url, old_root, old_path_board, new_root, new_path_board );
+}
+
+
+const bool DBTREE::move_board( const std::string& url_old, const std::string& url_new )
+{
+    return get_root()->move_board( url_old, url_new, false );
 }
 
 
@@ -153,9 +168,37 @@ const XML::Document& DBTREE::get_xml_document()
 }
 
 
-const std::map< std::string, std::string >& DBTREE::get_xml_etc()
+const std::list< DBTREE::ETCBOARDINFO >& DBTREE::get_etcboards()
 {
-    return get_root()->xml_etc();
+    return get_root()->get_etcboards();
+}
+
+
+bool DBTREE::add_etc( const std::string& url, const std::string& name, const std::string& basicauth, const std::string& id )
+{
+    return get_root()->add_etc( url, name, basicauth, id );
+}
+
+
+bool DBTREE::move_etc( const std::string& url_old, const std::string& url_new,
+               const std::string& name_old, const std::string& name_new,
+               const std::string& basicauth, const std::string& boardid )
+{
+    return get_root()->move_etc( url_old, url_new,
+                                 name_old, name_new,
+                                 basicauth, boardid );
+}
+
+
+bool DBTREE::remove_etc( const std::string& url, const std::string& name )
+{
+    return get_root()->remove_etc( url, name );
+}
+
+
+void DBTREE::save_etc()
+{
+    get_root()->save_etc();
 }
 
 
@@ -176,10 +219,42 @@ const std::string DBTREE::board_id( const std::string& url )
     return DBTREE::get_board( url )->get_id();
 }
 
-// 更新時間
+// 更新時間( time_t )
 const time_t DBTREE::board_time_modified( const std::string& url )
 {
-    return DBTREE::get_board( url )->time_modified();
+    return DBTREE::get_board( url )->get_time_modified();
+}
+
+// 板の更新時間( 文字列 )
+const std::string DBTREE::board_date_modified( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_date_modified();
+}
+
+// 板の更新時間( 文字列 )をセット
+void DBTREE::board_set_date_modified( const std::string& url, const std::string& date )
+{
+    DBTREE::get_board( url )->set_date_modified( date );
+}
+
+const std::string& DBTREE::board_get_modified_localrule( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_modified_localrule();
+}
+
+void DBTREE::board_set_modified_localrule( const std::string& url, const std::string& modified )
+{
+    DBTREE::get_board( url )->set_modified_localrule( modified );
+}
+
+const std::string& DBTREE::board_get_modified_setting( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_modified_setting();
+}
+
+void DBTREE::board_set_modified_setting( const std::string& url, const std::string& modified )
+{
+    DBTREE::get_board( url )->set_modified_setting( modified );
 }
 
 
@@ -461,6 +536,31 @@ time_t DBTREE::board_write_leftsec( const std::string& url )
     return DBTREE::get_board( url )->get_write_leftsec();
 }
 
+const int DBTREE::board_get_number_max_res( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_number_max_res();
+}
+
+void DBTREE::board_set_number_max_res( const std::string& url, const int number )
+{
+    DBTREE::get_board( url )->set_number_max_res( number );
+}
+
+const time_t DBTREE::board_get_live_sec( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_live_sec();
+}
+
+void DBTREE::board_set_live_sec( const std::string& url, time_t sec )
+{
+    DBTREE::get_board( url )->set_live_sec( sec );
+}
+
+const time_t DBTREE::board_last_access_time( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_last_access_time();
+}
+
 
 /////////////////////////////////////////////////
 
@@ -536,11 +636,22 @@ std::list< std::string > DBTREE::get_abone_list_regex_thread( const std::string&
     return DBTREE::get_board( url )->get_abone_list_regex_thread();
 }
 
+const int DBTREE::get_abone_number_thread( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_number_thread();
+}
+
+const int DBTREE::get_abone_hour_thread( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_hour_thread();
+}
+
 
 void DBTREE::reset_abone_thread( const std::string& url,
-                                 std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs )
+                                 std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs,
+                                 const int number, const int hour )
 {
-    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs );
+    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour );
 }
 
 /////////////////////////////////////////////////
@@ -555,16 +666,14 @@ const bool DBTREE::article_is_cached( const std::string& url )
 // 拡張子付き
 const std::string DBTREE::article_id( const std::string& url )
 {
-    std::string id =  DBTREE::get_article( url )->get_id();
-    return id;
+    return DBTREE::get_article( url )->get_id();
 }
 
 
 // idから拡張子を取ったもの
 const std::string DBTREE::article_key( const std::string& url )
 {
-    std::string key = DBTREE::get_article( url )->get_key();
-    return key;
+    return DBTREE::get_article( url )->get_key();
 }
 
 
@@ -580,7 +689,7 @@ const std::string DBTREE::article_since_date( const std::string& url )
 }
 
 
-// スレの更新時間( size_t )
+// スレの更新時間( time_t )
 const time_t DBTREE::article_time_modified( const std::string& url )
 {
     return DBTREE::get_article( url )->get_time_modified();
@@ -593,6 +702,11 @@ const std::string DBTREE::article_date_modified( const std::string& url )
     return DBTREE::get_article( url )->get_date_modified();
 }
 
+// スレの更新時間( 文字列 )をセット
+void DBTREE::article_set_date_modified( const std::string& url, const std::string& date )
+{
+    DBTREE::get_article( url )->set_date_modified( date );
+}
 
 const int  DBTREE::article_hour( const std::string& url )
 {
@@ -677,9 +791,20 @@ const int DBTREE::article_number_new( const std::string& url )
     return DBTREE::get_article( url )->get_number_new();
 }
 
-void DBTREE::article_download_dat( const std::string& url )
+const bool DBTREE::article_is_loading( const std::string& url )
 {
-    DBTREE::get_article( url )->download_dat();
+    return DBTREE::get_article( url )->is_loading();
+}
+
+void DBTREE::article_download_dat( const std::string& url, const bool check_update )
+{
+    DBTREE::get_article( url )->download_dat( check_update );
+}
+
+
+void DBTREE::article_stop_load( const std::string& url )
+{
+    DBTREE::get_article( url )->stop_load();
 }
 
 
@@ -688,7 +813,6 @@ const int DBTREE::article_get_speed( const std::string& url )
     return DBTREE::get_article( url )->get_speed();
 }
 
-
 const std::string& DBTREE::get_agent( const std::string& url )
 {
     return DBTREE::get_board( url )->get_agent();
@@ -714,6 +838,13 @@ const int DBTREE::get_proxy_port_w( const std::string& url )
     return DBTREE::get_board( url )->get_proxy_port_w();
 }
 
+
+const std::string DBTREE::localrule( const std::string& url )
+{
+    return DBTREE::get_board( url )->localrule();
+}
+
+
 const std::string DBTREE::settingtxt( const std::string& url )
 {
     return DBTREE::get_board( url )->settingtxt();
@@ -791,9 +922,9 @@ const std::string DBTREE::create_newarticle_message( const std::string& url, con
 
 
 // キャッシュ削除
-void DBTREE::delete_article( const std::string& url )
+void DBTREE::delete_article( const std::string& url, const bool cache_only )
 {
-    DBTREE::get_article( url )->delete_cache();
+    DBTREE::get_article( url )->delete_cache( cache_only );
 }
 
 
@@ -908,6 +1039,22 @@ void DBTREE::set_abone_chain( const std::string& url, bool set )
 }
 
 
+const bool DBTREE::is_bookmarked_thread( const std::string& url )
+{
+    return DBTREE::get_article( url )->is_bookmarked_thread();
+}
+
+void DBTREE::set_bookmarked_thread( const std::string& url, bool bookmarked )
+{
+    DBTREE::get_article( url )->set_bookmarked_thread( bookmarked );
+}
+
+
+const int DBTREE::get_num_bookmark( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_num_bookmark();
+}
+
 const bool DBTREE::is_bookmarked( const std::string& url, int number )
 {
     return DBTREE::get_article( url )->is_bookmarked( number );
