@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //
 // アイコンの管理クラス
@@ -14,21 +14,40 @@ namespace ICON
 {
     enum
     {
-        JD16,
+        NONE = -1,
+
+        JD16 = 0,
         JD32,
         JD48,
+        JD96,
+
+        BKMARK_UPDATE,
+        BKMARK,
+        BKMARK_THREAD,
 
         UPDATE,
+        NEWTHREAD,
+        NEWTHREAD_HOUR,
         CHECK,
         DOWN,
+        WRITE,
+        POST,
+        POST_REFER,
         LOADING,
         LOADING_STOP,
 
         DIR,
+        FAVORITE,
+
         BOARD,
         BOARD_UPDATE,
+        BOARD_UPDATED,
+
         THREAD,
         THREAD_UPDATE,
+        THREAD_UPDATED,
+        THREAD_OLD,
+
         IMAGE,
         LINK,
 
