@@ -11,7 +11,7 @@
 
 #include "jdlib/miscutil.h"
 
-#include "global.h"
+#include "type.h"
 #include "dndmanager.h"
 #include "sharedbuffer.h"
 #include "cache.h"
